==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListWorkflowRunActionExpressionTracesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionName The workflow action name.
 * @property name Site name.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property runName The workflow run name.
 * @property workflowName The workflow name.
 */
public data class ListWorkflowRunActionExpressionTracesPlainArgs(
    public val actionName: String,
    public val name: String,
    public val resourceGroupName: String,
    public val runName: String,
    public val workflowName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs =
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs.builder()
            .actionName(actionName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .runName(runName.let({ args0 -> args0 }))
            .workflowName(workflowName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListWorkflowRunActionExpressionTracesPlainArgs].
 */
@PulumiTagMarker
public class ListWorkflowRunActionExpressionTracesPlainArgsBuilder internal constructor() {
    private var actionName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    private var runName: String? = null

    private var workflowName: String? = null

    /**
     * @param value The workflow action name.
     */
    @JvmName("bputqjajeyqwtage")
    public suspend fun actionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.actionName = mapped
    }

    /**
     * @param value Site name.
     */
    @JvmName("dbpcpniojxekihnk")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("eoetngcifanbmgnt")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The workflow run name.
     */
    @JvmName("gxkidradygjogghq")
    public suspend fun runName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.runName = mapped
    }

    /**
     * @param value The workflow name.
     */
    @JvmName("opivjbjmsijufhje")
    public suspend fun workflowName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workflowName = mapped
    }

    internal fun build(): ListWorkflowRunActionExpressionTracesPlainArgs =
        ListWorkflowRunActionExpressionTracesPlainArgs(
            actionName = actionName ?: throw PulumiNullFieldException("actionName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            runName = runName ?: throw PulumiNullFieldException("runName"),
            workflowName = workflowName ?: throw PulumiNullFieldException("workflowName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListWorkflowRunActionExpressionTracesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionName The workflow action name.
 * @property name Site name.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property runName The workflow run name.
 * @property workflowName The workflow name.
 */
public data class ListWorkflowRunActionExpressionTracesPlainArgs(
    public val actionName: String,
    public val name: String,
    public val resourceGroupName: String,
    public val runName: String,
    public val workflowName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs =
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionExpressionTracesPlainArgs.builder()
            .actionName(actionName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .runName(runName.let({ args0 -> args0 }))
            .workflowName(workflowName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListWorkflowRunActionExpressionTracesPlainArgs].
 */
@PulumiTagMarker
public class ListWorkflowRunActionExpressionTracesPlainArgsBuilder internal constructor() {
    private var actionName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    private var runName: String? = null

    private var workflowName: String? = null

    /**
     * @param value The workflow action name.
     */
    @JvmName("kxbhlvdhekxmvkty")
    public suspend fun actionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.actionName = mapped
    }

    /**
     * @param value Site name.
     */
    @JvmName("sskvjxgafivmqhby")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("odnlqvgvfifpsill")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The workflow run name.
     */
    @JvmName("mglcpwrkxjenhqti")
    public suspend fun runName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.runName = mapped
    }

    /**
     * @param value The workflow name.
     */
    @JvmName("gfbvlniqyoqxovdi")
    public suspend fun workflowName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workflowName = mapped
    }

    internal fun build(): ListWorkflowRunActionExpressionTracesPlainArgs =
        ListWorkflowRunActionExpressionTracesPlainArgs(
            actionName = actionName ?: throw PulumiNullFieldException("actionName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            runName = runName ?: throw PulumiNullFieldException("runName"),
            workflowName = workflowName ?: throw PulumiNullFieldException("workflowName"),
        )
}
